<?php
/**
 * Enter description here ...
 *
 * @package Logic
 * @author  luistavares
 *
 */
class VinculoLogic{

    private $_idVinculo;
    private $_pessoa;
    private $_vinculo;
    private $_vinculoH;
    private $_mesCompetencia;

    const CPF_NAO_CADASTRADO = 'Pessoa n&atilde;o possui CPF cadastrado!';
    const HISTORICO_NAO_CADASTRADO = 'Pessoa n&atilde;o possui Hist&oacute;rico cadastrado!';
    const CPF_CADASTRADO = 'Cpf Cadastrado';
    const IDADE_MINIMA = 14;
    const PISPASEP_NAO_CADASTRADO = 'Pessoa n&atilde;o possui PISPASEP cadastrado!';
    const PISPASEP_CADASTRADO = 'PISPASEP Cadastrado';


    const DTRESCISAO_INVALIDA = 'Data de Rescis&atilde;o deve ser posterior a data de Admiss&atilde;o.';


    public function __construct() {

        $this->_vinculo = new GpevinculomEntity();
        $this->_vinculoH = new GpevinculohEntity();
        $this->_pessoa = new GpepessoahEntity();
        $this->_mesCompetencia = new TkDateTime();
    }


    /**
     * Enter description here ...
     *
     * @param integer    $nrOrgTrab   Numero da Organizacao de Trabalho.
     * @param integer    $nrPessoa    Numero da Pessoa.
     * @param string     $cdMatricula Matricula do Vinculo.
     * @param TkDateTime $dtAdmissao  Data de Admissao do Vinculo.
     * @param TkDateTime $dtRescisao  Data de Rescisao do Vinculo.
     *
     * @throws Exception $e Propaga.
     * @return void
     */
    public function incluiVinculoMestre(
        $nrOrgTrab, $nrPessoa, $cdMatricula, TkDateTime $dtAdmissao, TkDateTime $dtRescisao
    ){

        try {

            $vinculo = new GpevinculomEntity();

            // Verifica se existe o mestre. A funcao retornaVinculo agora tem um novo parametro, que eh estrutura.
            $objVinculo = $vinculo->retornaVinculoPorMatricula($nrOrgTrab, $cdMatricula);
            if (is_object($objVinculo) === false) {
                // Dados necessarios para o strategy.
                /* $coluna = 'NRVINCULOM';
                $tabela = 'GPE_VINCULOM';
                $step = '1';
                $pk = array(
                    'NRVINCULOM', 'NRORG',
                );
                $param = 'NRORG = '.$nrOrgTrab;
                $this->_idVinculo = GeraId::get($coluna, $tabela, $step, $pk, $param);
                */

                // Cria novo mestre.
                $this->_idVinculo = $vinculo->novoMestre($nrPessoa, $nrOrgTrab, $dtAdmissao, $dtRescisao, $cdMatricula);
            } else {
                $this->_idVinculo = $objVinculo->getNrvinculom();
                // Atualiza o vinculo.
                $objVinculo->setCdmatricula($cdMatricula);
                $objVinculo->setNrpessoa($nrPessoa);
                $objVinculo->setDtadmissaovinc($dtAdmissao);
                $objVinculo->setDtrescisaovinc($dtRescisao);
                $objVinculo->persist();
            }

            unset($vinculo);
            unset($objVinculo);
        } catch(Exception $e){
            throw $e;
        }

    }


    /**
     * Enter description here ...
     *
     * @param integer $nrOrgTrab  Numero da Organizacao de Trabalho.
     * @param integer $nrVinculom Numero do Vinculo.
     *
     * @throws Exception $e Propaga.
     * @return void
     */
    public function deletaVinculo($nrOrgTrab, $nrVinculom){
        try{

            $vinculoH = new GpevinculohEntity();
            $objVinculoH = $vinculoH->retornaHistoricos($nrOrgTrab, $nrVinculom);
            if (count($objVinculoH) === 0) {
                // Destroi mestre.
                $vinculo = new GpevinculomEntity();
                $vinculo->destroiMestre($nrVinculom, $nrOrgTrab);

                unset($vinculo);
            }
        } catch(Exception $e){
            throw $e;
        }
        unset($vinculoH);
        unset($objVinculoH);

    }


    /**
     * Enter description here ...
     *
     * @param integer $nrOrgTrab  Numero da Organizacao de Trabalho.
     * @param integer $nrVinculom Numero do Vinculo.
     *
     * @throws Exception $e Propaga.
     * @return void
     */
    public function deletaVinculoHistorico($nrOrgTrab, $nrVinculom){
        try{

            $conn = TkDbAdapter::getWorkConnection();
            $conn->beginTransaction();

            $vinculoH = new GpevinculohEntity();
            $vinculoH->carregaVinculosHistoricos($nrOrgTrab, $nrVinculom);
            $vinculoH->apagaVinculosHistoricos();
            $vinculoH->persist();

            $conn->commit();

            unset($vinculoH);

        } catch(Exception $e){
            $conn->rollback();
            throw $e;
        }
    }


    /**
     * Enter description here ...
     *
     * @return Ambigous <boolean, nrvinculom, NULL>
     */
    public function getIdvinculom(){
        return $this->_idVinculo;
    }


    /**
     * Enter description here ...
     *
     * @param integer    $nrOrgTrab      Numero da Organizacao de Trabalho.
     * @param integer    $nrVinculom     Numero do Vinculo.
     * @param TkDateTime $mesCompetencia Mes de Competencia.
     *
     * @return boolean
     */
    public function verificaVinculoHistorico($nrOrgTrab, $nrVinculom, TkDateTime $mesCompetencia){

        $vinculoh = new GpevinculohEntity();

        $objVinculoH = $vinculoh->retornaVinculoHistoricoMesCompetencia($nrOrgTrab, $nrVinculom, $mesCompetencia);

        if (is_object($objVinculoH) === true) {
            return $objVinculoH;
        }

        unset($vinculoh);
        //unset($objVinculoH);
        return false;
    }


    /**
     * Verifica se Parceiro de Neg�cio possui Pessoa cadastrada.
     *
     * @param integer $nrorg         N�mero da Organiza��o.
     * @param integer $nrparcnegocio N�mero do Parceiro de Neg�cio.
     *
     * @return $nrpessoa
     *
     * @author luistavares - 12/05/2011
     */
    public function verificaPessoa($nrorg, $nrparcnegocio){
        try {
            $pessoa = new GpepessoaEntity();
            $obj_pessoa = $pessoa->retornaPessoaPorParceiro($nrorg, $nrparcnegocio);

            if (is_object($obj_pessoa) === true) {
                $nrpessoa = $obj_pessoa->getNrpessoa();
                return $nrpessoa;
            } else {
                return 0;
            }
        } catch (Exception $e) {
            return 0;
        }
    }


    /**
     * Verifica se a Pessoa possui CPF.
     *
     * @param integer $nrpessoa       N�mero da Pessoa.
     * @param integer $nrorg          N�mero da Organiza��o.
     * @param integer $dtmescompetenc Mes de Competencia.
     *
     * @return boolean
     *
     * @author luistavares 12/05/2011
     *         brunofeliciano - 28/06/2011 - inclusao do parametro $dtmescompetenc.
     *         brunofeliciano - 14/07/2011 - substuticao do parametro $nrparcnegocio por $nrpessoa.
     */
    public function verificaCPF($nrpessoa, $nrorg, $dtmescompetenc){

        /* $nrpessoa = $this->verificaPessoa($nrorg, $nrparcnegocio); */
        $pessoah = new GpepessoahEntity();
        $obj_pessoah = $pessoah->retornaHistoricoAtualPorPessoa($nrorg, $nrpessoa, $dtmescompetenc);

        if (is_object($obj_pessoah) === true) {
            $cpf = $obj_pessoah->getNrcpfpessoa();

            if (strlen($cpf) > 0) {
                return $this::CPF_CADASTRADO;
            } else {
                return $this::CPF_NAO_CADASTRADO;
            }
        } else {
            return $this::HISTORICO_NAO_CADASTRADO;
        }
    }


     /**
     * Verifica Idade do Parceiro de Negocio.
     *
     * @param integer $nrpessoa       N�mero da Pessoa.
     * @param integer $nrorg          N�mero da Organiza��o.
     * @param string  $dtmescompetenc Data de Competencia.
     *
     * @return boolean
     * @author luistavares - 12/05/2011
     *         brunofeliciano - 28/06/2011 - inclusao do parametro $dtmescompetenc.
     *         brunofeliciano - 14/07/2011 - substuticao do parametro $nrparcnegocio por $nrpessoa.
     */
    public function verificaIdade($nrpessoa, $nrorg, $dtmescompetenc){
        /* $nrpessoa = $this->verificaPessoa($nrorg, $nrparcnegocio); */
        $idade = PessoaLogic::getIdadePessoa($nrpessoa, $nrorg, $dtmescompetenc);

        if ($idade >= $this::IDADE_MINIMA) {
            return true;
        } else {
            return false;
        }
    }


    /**
     * Verifica PISPASEP do Parceiro de Negocio.
     *
     * @param integer $nrpessoa       N�mero da Pessoa.
     * @param integer $nrorg          N�mero da Organiza��o.
     * @param string  $dtmescompetenc Data de Competencia.
     *
     * @return boolean
     *
     * @author luistavares - 12/05/2011
     *         brunofeliciano - 28/06/2011 - inclusao do parametro $dtmescompetenc.
     *         brunofeliciano - 14/07/2011 - substuticao do parametro $nrparcnegocio por $nrpessoa.
     */
    public function verificaPISPASEP($nrpessoa, $nrorg, $dtmescompetenc){

        /* $nrpessoa = $this->verificaPessoa($nrorg, $nrparcnegocio); */
        $pessoah = new GpepessoahEntity();
        $obj_pessoah = $pessoah->retornaHistoricoAtualPorPessoa($nrorg, $nrpessoa, $dtmescompetenc);

        if (is_object($obj_pessoah) === true) {
            $pispasep = $obj_pessoah->getNrpispaseppes();

            if (strlen($pispasep) > 0) {
                return $this::PISPASEP_CADASTRADO;
            } else {
                return $this::PISPASEP_NAO_CADASTRADO;
            }
        } else {
            return $this::HISTORICO_NAO_CADASTRADO;
        }
    }


    /**
     * Insere a Altera��o de Salario logo ap�s o 1� registro de Historico do v�nculo.
     *
     * @param integer $nrVinculom N�mero do Vinculo.
     * @param integer $nrOrg      Numero da organizacao do vinculo.
     * @param float   $vrSalario  Valor do Sal�rio do vinculo.
     *
     * @return Ambiguous
     *
     * @author brunofeliciano - 18/04/2011
     *         alessandrobartels - 30/06/2011 - Modificado logica do metodo. Retirado parametros de auditoria
     *         brunofeliciano - 30/08/2011 - Modificado metodo para tratar inclusao em seu respectivo Entity.
     */
    public function insereAlteracaoSalario($nrVinculom, $nrOrg, $vrSalario){

        $alteracaoSalario = new GpealtesalarioEntity();
        $obj_alteracaoSalario = $alteracaoSalario->retornaAlteSalarioporVinculo($nrVinculom, $nrOrg);

        /* Verificacao pelo is_object() pois $obj_alteracaoSalario � Entity */
        if (is_object($obj_alteracaoSalario) === false) {
            /* Inclusao da primeira alteracao salarial para o vinculo */

            $obj_vinculo = new GpevinculomEntity();
            $vinculo = $obj_vinculo->retornaVinculo($nrVinculom, $nrOrg);

            $dataAltera = '01/01/00'; /* Data inicial default */
            $nrOcorrencia = 1; /* Numero de Ocorrencia inicial default */

            /* Data de admissao do vinculo � igual a data da primeira Alteracao Salarial */
            if (is_object($vinculo) === true) {
                $dataAltera = $vinculo->getDtadmissaovinc();
            }

            $dataAltera = new TkDateTime($dataAltera);

            $alteracaoSalario->incluiAlteracaoSalario(
                $nrVinculom, $nrOrg, $vrSalario, $alteracaoSalario::ALTERACAO_SALARIO_ADMISSAO, $dataAltera,
                $nrOcorrencia
            );

            return true;
        } else {
            return false;
        }

    }


    /**
     * Insere a Altera��o de Salario logo ap�s o 1� registro de Historico do v�nculo.
     *
     * @param integer $nrVinculom N�mero do Vinculo.
     * @param integer $nrOrg      Numero da organizacao do vinculo.
     *
     * @return Ambiguous
     *
     * @author brunofeliciano - 30/08/2011
     *         alessandrobartels - 21/01/2013
     */
    public function insereAltSituFuncional($nrOrg, $nrVinculom, $nrSituFunc, $dtInicioSituFunc){

        try {

            $altSituFuncional = new GpealtesitufuncEntity();

            $altSituFuncional->setNrorg($nrOrg);
            $altSituFuncional->setNrvinculom($nrVinculom);
            $altSituFuncional->setNrsitufuncm($nrSituFunc);
            $altSituFuncional->setDtinisitufunc($dtInicioSituFunc);

            $altSituFuncional->persist();

            unset ($altSituFuncional);
        } catch (Exception $e) {
            throw $e;
        }


    }

    /**
     * @param $nrOrg
     * @param $nrVinculom
     * @param $nrSituFunc
     * @param $dtInicioSituFunc
     * @return void
     * @author alessandrobartels 23/01/2013
     */
    public function alteraAltSituFuncional($nrOrg, $nrVinculom, $nrSituFunc, $dtInicioSituFunc){

        try{
            $altSituFuncional = new GpealtesitufuncEntity();
            $listaAltSitFunc = $altSituFuncional->retornaAlteSituFuncporVinculo($nrVinculom, $nrOrg);

            $dtInicioSituFunc = new TkDateTime($dtInicioSituFunc, TkDateTime::FORMAT_DATE);
            foreach ($listaAltSitFunc as $altSituFunc){
                if ($dtInicioSituFunc->equals($altSituFunc->getDtinisitufunc(), TkDateTime::FORMAT_DATE)
                    && $altSituFunc->getNrsitufuncm() !== $nrSituFunc
                ){
                    $altSituFunc->setNrsitufuncm($nrSituFunc);
                    $altSituFunc->persist();
                    break;
                }
            }
            unset($altSituFuncional);

        } catch (Exception $e){
            throw $e;
        }

    }

    /**
     * @throws Exception
     * @param $nrOrg
     * @param $nrVinculom
     * @param $nrEscala
     * @param $dtInicioEscala
     * @param $nrMotivoEscala
     * @return void
     *
     * @author alessandrobartels 22/01/2013
     */
    public function insereAlteracaoEscala($nrOrg, $nrVinculom, $nrEscala, $dtInicioEscala){
        try{
            $altEscala = new GpeAlteescalaEntity();

            $altEscala->setNrorg($nrOrg);
            $altEscala->setNrvinculom($nrVinculom);
            $altEscala->setNrescalatrabm($nrEscala);
            $altEscala->setDtiniescala($dtInicioEscala);
//            $altEscala->setNrmotivoescala($nrMotivoEscala);

            $altEscala->persist();
            unset($altEscala);

        } catch (Exception $e){
            throw $e;
        }
    }

    /**
     * @param $nrOrg
     * @param $nrVinculom
     * @param $nrEscala
     * @param $dtInicioEscala
     * @param $nrMotivoEscala
     * @return void
     *
     * @author alessandrobartels - 24/01/2013
     */
    public function alteraAltEscala($nrOrg, $nrVinculom, $nrEscala, $dtInicioEscala){
        try{
            $altEscala = new GpeAlteescalaEntity();
            $listaAltEscala = $altEscala->retornaAlteracaoEscalaPorVinculo($nrOrg, $nrVinculom);

            $dtInicioEscala = new TkDateTime($dtInicioEscala, TkDateTime::FORMAT_DATE);
            foreach ($listaAltEscala as $altEsc){
                if ($dtInicioEscala->equals($altEsc->getDtiniescala(), TkDateTime::FORMAT_DATE)
                    && $altEsc->getNrescalatrabm() !== $nrEscala
                ){
                    $altEsc->setNrescalatrabm($nrEscala);
//                    $altEsc->setNrmotivoescala($nrMotivoEscala);
                    $altEsc->persist();
                    break;
                }
            }

            unset($altEscala);
        } catch (Exception $e){
            throw $e;
        }
    }


    public function insereAlteracaoOcupacao($nrOrg, $nrVinculom, $nrOcupacao, $dtInicioOcupacao){
        try{
            $ocupacao = new GpeOcupacaomEntity(null, $nrOrg);
            $objOcupacao = $ocupacao->retornaOcupacao($nrOcupacao);
            $nrTipoOcupacao = $objOcupacao->getNrtipoocupacao();
            unset($ocupacao);
            unset($objOcupacao);

            $altOcupacao = new GpeAlteocupacaoEntity();
            $altOcupacao->setNrorg($nrOrg);
            $altOcupacao->setNrvinculom($nrVinculom);
            $altOcupacao->setNrocupacaom($nrOcupacao);
            $altOcupacao->setDtiniocupacao($dtInicioOcupacao);
            $altOcupacao->setNrtipoocupacao($nrTipoOcupacao);

            $altOcupacao->persist();
            unset($altOcupacao);

        } catch (Exception $e){
            throw $e;
        }
    }


    public function alteraAltOcupacao($nrOrg, $nrVinculom, $nrOcupacao, $dtInicioOcupacao, $tpOcupacao){
        try{
            $ocupacao = new GpeOcupacaomEntity(null, $nrOrg);
            $objOcupacao = $ocupacao->retornaOcupacao($nrOcupacao);
            $nrTipoOcupacao = $objOcupacao->getNrtipoocupacao();
            unset($ocupacao);
            unset($objOcupacao);

            $altOcupacao = new GpeAlteocupacaoEntity();
            $listaAltOcupacao = $altOcupacao->retornaAlteracaoOcupacaoVinculo($nrOrg, $nrVinculom);
            $dtInicioOcupacao = new TkDateTime($dtInicioOcupacao, TkDateTime::FORMAT_DATE);
            foreach ($listaAltOcupacao as $altOcup){
                if ($dtInicioOcupacao->equals($altOcup->getDtiniocupacao(), TkDateTime::FORMAT_DATE)
                    && $altOcup->getNrocupacaom() !== $nrOcupacao
                    && $altOcup->getNrtipoocupacao() === (string)$tpOcupacao
                ){
                    $altOcup->setNrocupacaom($nrOcupacao);
                    $altOcup->setNrtipoocupacao($nrTipoOcupacao);
                    $altOcup->persist();
                    break;
                }
            }

            unset($altOcupacao);

        } catch (Exception $e){
            throw $e;
        }
    }


    public function insereMovimentacao($nrOrg, $mesCompetencia, $nrVinculom, $nrEstrutura, $tpTransferencia, $dtInicioMovimentacao, $nrTpmovtransfm = null){
        try{
            $estrutura = new EstruturamEntity(null, $nrOrg, $mesCompetencia);
            $objEstrutura = $estrutura->retornaEstrutura($nrEstrutura);
            $nrTipoEstrutura = $objEstrutura->getNrtipoestrutura();
            $idAtualizaAcerto = 0;
            unset($estrutura);
            unset($objEstrutura);

            $movimentacao = new GpeMovimentacaoEntity();
            $movimentacao->setNrorg($nrOrg);
            $movimentacao->setNrvinculom($nrVinculom);
            $movimentacao->setNrestruturam($nrEstrutura);
            $movimentacao->setNrtipotransfer($tpTransferencia);
            $movimentacao->setDtinimoviment($dtInicioMovimentacao);
            $movimentacao->setNrtipoestrutura($nrTipoEstrutura);
            $movimentacao->setNrtpmovtransfm($nrTpmovtransfm);
            $movimentacao->setIdatualizaacerto($idAtualizaAcerto);

            $movimentacao->persist();
            unset($movimentacao);

        }catch (Exception $e){
            throw $e;
        }
    }


    public function alteraMovimentacao($nrOrg, $mesCompetencia, $nrVinculom, $nrEstrutura, $dtInicioMovimentacao, $tpEstrutura){
        try{
            $estrutura = new EstruturamEntity(null, $nrOrg, $mesCompetencia);
            $objEstrutura = $estrutura->retornaEstrutura($nrEstrutura);
            $nrTipoEstrutura = $objEstrutura->getNrtipoestrutura();
            unset($estrutura);
            unset($objEstrutura);

            $movimentacao = new GpeMovimentacaoEntity();
            $listaMovimentacoes = $movimentacao->retornaMovimentacoesVinculo($nrOrg, $nrVinculom); // BORBA 06/05/2013
            $dtInicioMovimentacao = new TkDateTime($dtInicioMovimentacao, TkDateTime::FORMAT_DATE);
            foreach ($listaMovimentacoes as $altMovimentacao){
                if ($dtInicioMovimentacao->equals($altMovimentacao->getDtinimoviment(), TkDateTime::FORMAT_DATE)
                    && $altMovimentacao->getNrestruturam() !== $nrEstrutura
                    && $altMovimentacao->getNrtipotransfer() === (string)$tpEstrutura
                ){
                    $altMovimentacao->setNrestruturam($nrEstrutura);
                    $altMovimentacao->setNrtipoestrutura($nrTipoEstrutura);
                    $altMovimentacao->persist();
                }
            }
            unset($movimentacao);

        }catch (Exception $e){
            throw $e;
        }
    }

    /**
     * Retorna o periodo em dias da duracao do vinculo.
     *
     * @param string $dtAdmissaoVinc Data de Admissao do Vinculo.
     * @param string $dtRescisaoVinc Data de Recisao do Vinculo.
     *
     * @return number
     */
    public function retornaDuracaoVinculo($dtAdmissaoVinc, $dtRescisaoVinc){
        $vinculo = new GpevinculomEntity();
        $qtdias = $vinculo->retornaDuracaoVinculo($dtAdmissaoVinc, $dtRescisaoVinc);
        return $qtdias;
    }


    /**
     * Retorna o nome da pessoa relacionada ao vinculo sem acento e em caixa alta.
     * Insere o nome da pessoa informada no vinculom no campo NMVINCULOM.
     *
     * @param integer $nrOrg            Numero da organizacao.
     * @param integer $nrPessoa         Numero da pessoa setada no vinculo.
     * @param string  $dtMesCompetencia Data de competencia.
     *
     * @return String
     *
     * @author thalesvalias - 23/04/2012
     */
    public function retornaNomePessoaNoVinculo($nrOrg, $nrPessoa, $dtMesCompetencia) {

        $pessoa = new GpepessoahEntity();
        $pessoa = $pessoa->retornaHistoricoAtualPorPessoa($nrOrg, $nrPessoa, $dtMesCompetencia);

        if (is_object($pessoa) === true) {

            $nomePessoa = $pessoa->getNmpessoa();

            if ($nomePessoa !== null) {

                $acentuado = 'ÀÁÂÃÄÅÆÇÈÉÊËÌÍÎÏÐÑÒÓÔÕÖØÙÚÛÜÝÞßàáâãäåæçèéêëìíîïðñòóôõöøùúûýýþÿ';
                $naoAcentuado = 'AAAAAAACEEEEIIIIDNOOOOOOUUUUYBSAAAAAAACEEEEIIIIDNOOOOOOUUUYYBY';

    //            $nomePessoa = utf8_decode($nomePessoa);
                $nomePessoa = strtr(utf8_decode($nomePessoa), utf8_decode($acentuado), $naoAcentuado);
                $nomePessoa = strtoupper(utf8_encode($nomePessoa));

                return $nomePessoa;
            } else {

                tk_warning('Não foi possível inserir o nome do vínculo de acordo com o nome da pessoa correspondente!');
            }
        } else {
            tk_warning('Objeto pessoa não encontrado!');
        }

    }


    /**
     * Retorna o nome da pessoa relacionada ao vinculo sem acento e em caixa alta.
     * Insere o nome da pessoa informada no vinculom no campo NMVINCULOM.
     *
     * @param integer $nrOrg            Numero da organizacao.
     * @param integer $nrPessoa         Numero da pessoa setada no vinculo.
     * @param string  $dtMesCompetencia Data de competencia.
     *
     * @return String
     *
     * @author thalesvalias - 23/04/2012
     */
    public function alteraNomePessoaNoVinculo($nrOrg, $nrPessoa, $dtMesCompetencia) {

        $pessoa = new GpepessoahEntity();
        $pessoa = $pessoa->retornaHistoricoAtualPorPessoa($nrOrg, $nrPessoa, $dtMesCompetencia);

        if (is_object($pessoa) === true) {

            $nomePessoa = $pessoa->getNmpessoa();

            if ($nomePessoa !== null) {

                $acentuado = 'ÀÁÂÃÄÅÆÇÈÉÊËÌÍÎÏÐÑÒÓÔÕÖØÙÚÛÜÝÞßàáâãäåæçèéêëìíîïðñòóôõöøùúûýýþÿ';
                $naoAcentuado = 'AAAAAAACEEEEIIIIDNOOOOOOUUUUYBSAAAAAAACEEEEIIIIDNOOOOOOUUUYYBY';

                //            $nomePessoa = utf8_decode($nomePessoa);
                $nomePessoa = strtr(utf8_decode($nomePessoa), utf8_decode($acentuado), $naoAcentuado);
                $nomePessoa = strtoupper(utf8_encode($nomePessoa));

                return $nomePessoa;
            } else {

                tk_warning('Não foi possível inserir o nome do vínculo de acordo com o nome da pessoa correspondente!');
            }
        } else {
            tk_warning('Objeto pessoa não encontrado!');
        }

    }


    private function getVinculoHistorico($nrOrg, $nrVinculo, $mesCompetencia){

        $vinculoH = $this->verificaVinculoHistorico($nrOrg, $nrVinculo, $mesCompetencia);
        if (is_object($vinculoH) === false){
            // insere novo historico
            $vinculoH = $this->_vinculoH->getUltimoVinculoHistorico($nrOrg, $mesCompetencia, $nrVinculo);
            $vinculoH->adicionaPersisteHistorico($mesCompetencia);
            //$vinculoH = $this->verificaVinculoHistorico($nrOrg, $nrVinculo, $mesCompetencia);
        }

    }


    public function atualizaEscalaVinculoHistorico($nrOrg, $nrVinculo, $dtMesCompetencia, $nrEscala){

        // Pesquisa se existe um vinculo para a data de competencia
        $this->_mesCompetencia->set($dtMesCompetencia);
        $this->_vinculoH->atualizaEscalaVinculoHistoricoPorAlteracao($nrOrg, $this->_mesCompetencia, $nrVinculo, $nrEscala);

    }




}