<?php
/**
 * Registro12SEFIP
 *
 * @package    Logic
 * @subpackage Registro/Sefip
 *
 * @author     felipesantos - 04/05/2015
 *
 */
class Registro12SEFIP extends RegistroSEFIP{

    /**
     *
     */
    const REGISTRO_12 = '12';

    private $_estrutura;
    private $_nrInscricao;
    private $_tpInscricao;
    private $_nrRecolhimento;
    private $_fpas;

    /**
     * Preparacao para a criacao do Registro 12.
     *
     * @param EstruturamEntity $estrutura   Instancia de EstruturamEntity.
     * @param array $remuneracao Valores de remuneração
     *
     * @return void
     *
     * @author felipesantos - 04/05/2015
     */
    public function geraRegistro12(EstruturamEntity $estrutura, $remuneracao){
        $this->_estrutura = $estrutura;

        $this->_nrRecolhimento = $this->getCodigoRecolhimento();
        $this->_fpas = $this->_estrutura->historico->getCdfpas();

        $this->_geraRegistro($remuneracao);
    }


    /**
     * Cria o Registro 12.
     *
     * @param array $remuneracao Valores de remuneração
     *
     * @return void
     *
     * @author felipesantos - 04/05/2015
     */
    private  function _geraRegistro($remuneracao){
        // Bloco 1 ao 3 eh gerado no pai.
        parent::geraRegistro(self::REGISTRO_12, $this->_tpInscricao, $this->_nrInscricao);

        // Bloco 4 | 018-053 | Preencher com zeros.
        $this->atribuiDado(parent::CARACTER_VAZIO, 36, parent::CARACTER_ZERO);

        // Bloco 5 | 054-068 | Dedução 13º Salário Licença Maternidade.
        $this->atribuiDado(parent::CARACTER_VAZIO, 15, parent::CARACTER_ZERO);

        // Bloco 6 | 069-083 | Receita Evento Desportivo / Patrocínio.
        $this->atribuiDado(parent::CARACTER_VAZIO, 15, parent::CARACTER_ZERO);

        // Bloco 7 | 084-084 | Indicativo Origem Receita.
        $this->atribuiDado(parent::CARACTER_VAZIO, 1, parent::CARACTER_BRANCO);

        // Bloco 8 | 085-099 | Comercialização da Produção - Pessoa Física.
        $this->atribuiDado(parent::CARACTER_VAZIO, 15, parent::CARACTER_ZERO);

        // Bloco 9 | 100-114 | Comercialização da Produção - Pessoa Jurídica.
        $this->atribuiDado(parent::CARACTER_VAZIO, 15, parent::CARACTER_ZERO);

        // Bloco 10 | 115-125 | Outras Informações Processo.
        $this->atribuiDado(parent::CARACTER_VAZIO, 11, parent::CARACTER_BRANCO);

        // Bloco 11 | 126-129 | Outras Informações Processo Ano.
        $this->atribuiDado(parent::CARACTER_VAZIO, 4, parent::CARACTER_BRANCO);

        // Bloco 12 | 130-134 | Outras Informações Vara/JCJ.
        $this->atribuiDado(parent::CARACTER_VAZIO, 5, parent::CARACTER_BRANCO);

        // Bloco 13 | 135-140 | Outras Informações Período Início.
        $this->atribuiDado(parent::CARACTER_VAZIO, 6, parent::CARACTER_BRANCO);

        // Bloco 14 | 141-146 | Outras Informações Período Fim.
        $this->atribuiDado(parent::CARACTER_VAZIO, 6, parent::CARACTER_BRANCO);

        // Bloco 15 | 147-161 | Compensação - Valor Corrigido.
        $this->_atribuiCompensacao($remuneracao[RegistroSEFIP::SEFIP_COMPEN_VLRCORR]);

        // Bloco 16 | 162-167 | Compensação - Período Início.
        $this->_atribuiCompensacaoPerIni($this->getCompetencia(), $remuneracao[RegistroSEFIP::SEFIP_COMPEN_VLRCORR]);

        // Bloco 17 | 168-173 | Compensação - Período Fim.
        $this->_atribuiCompensacaoPerFim($this->getCompetencia(), $remuneracao[RegistroSEFIP::SEFIP_COMPEN_VLRCORR]);

        // Bloco 18 | 174-188 | Recolhimento de Competências Anteriores - INSS.
        $this->atribuiDado(parent::CARACTER_VAZIO, 15, parent::CARACTER_ZERO);

        // Bloco 19 | 189-203 | Recolhimento de Competências Anteriores - Outras Entidades.
        $this->atribuiDado(parent::CARACTER_VAZIO, 15, parent::CARACTER_ZERO);

        // Bloco 20 | 204-218 | Recolhimento de Competências Anteriores - Comercialização da produção - INSS.
        $this->atribuiDado(parent::CARACTER_VAZIO, 15, parent::CARACTER_ZERO);

        // Bloco 21 | 219-233 | Recolhimento de Competências Anteriores - Comercialização da produção - Outras Entidades.
        $this->atribuiDado(parent::CARACTER_VAZIO, 15, parent::CARACTER_ZERO);

        // Bloco 22 | 234-248 | Recolhimento de Competências Anteriores - Receita Evento Desportivo/Patrocínio - INSS.
        $this->atribuiDado(parent::CARACTER_VAZIO, 15, parent::CARACTER_ZERO);

        // Bloco 23 | 249-263 | Parcelamento do FGTS - Categorias 01,02,03,05 e 06.
        $this->atribuiDado(parent::CARACTER_VAZIO, 15, parent::CARACTER_ZERO);

        // Bloco 24 | 264-278 | Parcelamento do FGTS - Categorias 04 e 07.
        $this->atribuiDado(parent::CARACTER_VAZIO, 15, parent::CARACTER_ZERO);

        // Bloco 25 | 279-293 | Parcelamento do FGTS - Valor Recolhido.
        $this->atribuiDado(parent::CARACTER_VAZIO, 15, parent::CARACTER_ZERO);

        // Bloco 26 | 294-308 | Valores pagos à Cooperativas de Trabalho.
        $this->_atribuiValorCooperativas($remuneracao[RegistroSEFIP::SEFIP_VALOR_NF_COOPER]);

        // Bloco 27 | 309-353 | Zeros. Preencher com '0'. Implementacao futura.
        $this->atribuiDado(parent::CARACTER_VAZIO, 45, parent::CARACTER_ZERO);

        // Bloco 28 | 354-359 | Brancos. Preencher com ' '.
        $this->atribuiDado(parent::CARACTER_VAZIO, 6, parent::CARACTER_BRANCO);

        // Bloco 29 | 360 | Final de linha. Inserir '*'.
        $this->atribuiDado(parent::CARACTER_VAZIO, 1, parent::CARACTER_ASTERISCO);
    }


    public function setNrInscricao($nrInscricao)
    {
        $this->_nrInscricao = $nrInscricao;
    }


    public function setTpInscricao($tpInscricao)
    {
        $this->_tpInscricao = $tpInscricao;
    }


    /**
     * Atribui Compensação - Valor Corrigido.
     *
     * @param number $vrCompensacao Valor de Compensação - Valor Corrigido.
     *
     * @return void
     *
     * @author felipesantos - 05/05/2015
     */
    private function _atribuiCompensacao($vrCompensacao){

        $codRecol = array(
            '145', '211', '307', '327', '345', '640', '660'
        );
        if ((array_search($this->_nrRecolhimento, $codRecol) !== false)) {
            $vrCompensacao = parent::CARACTER_ZERO;
        }

        if ($this->getIdRecolhimentoGPS() !== parent::IND_REC_GPS_NOPRAZO) {
            $vrCompensacao = parent::CARACTER_ZERO;
        }

        $this->atribuiDado($vrCompensacao, 15, parent::CARACTER_ZERO, parent::PREENCHE_ESQUERDA);
    }


    /**
     * Atribui Compensação - Período Início.
     *
     * @param string $dataInicio Compensação - Período Início (AAAA/MM).
     * @param number $vrCompensacao Valor de Compensação - Valor Corrigido.
     *
     * @return void
     *
     * @author felipesantos - 05/05/2015
     */
    private function _atribuiCompensacaoPerIni($dataInicio, $vrCompensacao){

        if ($vrCompensacao == 0) {
            $dataInicio = parent::CARACTER_BRANCO;
        }

        $codRecol = array(
            '145', '211', '307', '327', '345', '640', '660'
        );
        if ((array_search($this->_nrRecolhimento, $codRecol) !== false)) {
            $dataInicio = parent::CARACTER_BRANCO;
        }

        $this->atribuiDado($dataInicio, 6, parent::CARACTER_BRANCO, parent::PREENCHE_ESQUERDA);
    }


    /**
     * Atribui Compensação - Período Fim.
     *
     * @param string $dataFim Compensação - Período Fim (AAAA/MM).
     * @param number $vrCompensacao Valor de Compensação - Valor Corrigido.
     *
     * @return void
     *
     * @author felipesantos - 05/05/2015
     */
    private function _atribuiCompensacaoPerFim($dataFim, $vrCompensacao){

        if ($vrCompensacao == 0) {
            $dataFim = parent::CARACTER_BRANCO;
        }

        $codRecol = array(
            '145', '211', '307', '327', '345', '640', '660'
        );
        if ((array_search($this->_nrRecolhimento, $codRecol) !== false)) {
            $dataFim = parent::CARACTER_BRANCO;
        }

        $this->atribuiDado($dataFim, 6, parent::CARACTER_BRANCO, parent::PREENCHE_ESQUERDA);
    }


    /**
     * Atribui valor de cooperativas
     *
     * @param number $vrCooperat Valor pago à cooperativas de trabalho.
     *
     * @return void
     *
     * @author felipesantos - 07/05/2015
     */
    private function _atribuiValorCooperativas($vrCooperat){
        /**
        * Não pode ser informado para FPAS 604 no código de recolhimento 150, quando competência posterior a 10/2001.
        * Não pode ser informado para os códigos de recolhimento 130, 135, 145, 211, 307, 317, 327, 337, 345, 608, 640, 650 e 660.
        * Não pode ser informado na competência 13.
        · Não pode ser informado para os códigos de recolhimento 150 e 155 quando for exclusivo de retenção.
        · Não pode ser informado para o código de recolhimento 115 quando for exclusivo de Receita de Comercialização de Produção/Patrocínio e Eventos desportivo.
        * Não pode ser informado se FPAS da empresa for igual a 868 (empregador doméstico).
         */

        $codRecol = array(
            '130', '135', '145', '211', '307', '317', '327', '337', '345', '608', '640', '650', '660'
        );

        if ((($this->_fpas === '604' && $this->_nrRecolhimento === '150')
            || (array_search($this->_nrRecolhimento, $codRecol) !== false)
            || ($this->getCompetencia13())
            || ($this->_fpas === '868'))
        ) {
            $vrCooperat = parent::CARACTER_ZERO;
        }

        $this->atribuiDado($vrCooperat, 15, parent::CARACTER_ZERO, parent::PREENCHE_ESQUERDA);
    }
}